.. sqlparams documentation master file, created by
   sphinx-quickstart on Thu Dec 20 10:32:52 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to SQL Params's documentation!
======================================

Contents:

.. toctree::

   sqlparams


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
